==> nmrium-0.50.1.tgz: package/lib/component/elements/EditableColumn.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useCallback, useEffect, useImperativeHandle, useState, } from 'react';
import Input from './Input';
function extractNumber(val, type) {
    if (type === 'number' && typeof val !== 'number') {
        return Number(val.replaceAll(/[^\d.-]/g, ''));
    }
    return val;
}
const EditableColumn = forwardRef(function EditableColumn(props, ref) {
    const { onSave = () => null, value, type = 'text', style, onEditStart = () => null, editStatus = false, validate = () => true, textOverFlowEllipses = false, ...InputProps } = props;
    const [enabled, enableEdit] = useState();
    const [isValid, setValid] = useState(true);
    const [val, setVal] = useState(extractNumber(value, type));
    useEffect(() => {
        enableEdit(editStatus);
    }, [editStatus]);
    useImperativeHandle(ref, () => ({
        startEdit: () => {
            enableEdit(true);
        },
        closeEdit: () => {
            enableEdit(false);
        },
    }));
    const mouseClickCallback = useCallback((e) => {
        if (!e.target.classList.contains('editable-column')) {
            enableEdit(false);
            window.removeEventListener('mousedown', mouseClickCallback);
        }
    }, []);
    function startEditHandler() {
        window.addEventListener('mousedown', mouseClickCallback);
        onEditStart(true);
        enableEdit(true);
    }
    function editHandler(event) {
        const valid = validate(val);
        setValid(valid);
        // when press Enter or Tab
        if (valid && ['Enter', 'Tab'].includes(event.key)) {
            onSave(event);
            enableEdit(false);
        }
        // close edit mode if press Enter, Tab or Escape
        if (['Escape'].includes(event.key)) {
            enableEdit(false);
            window.removeEventListener('mousedown', mouseClickCallback);
        }
    }
    function handleChange(e) {
        setVal(e.target.value);
    }
    return (_jsxs("div", { style: {
            display: 'table',
            width: '100%',
            height: '100%',
            ...(textOverFlowEllipses
                ? { whiteSpace: 'nowrap', overflow: 'hidden', display: 'inline-flex' }
                : {}),
            ...style,
        }, className: "editable-column-input", onDoubleClick: startEditHandler, children: [!enabled && (_jsx("span", { style: {
                    display: 'table-cell',
                    verticalAlign: 'middle',
                    width: '100%',
                    ...(textOverFlowEllipses
                        ? { textOverflow: 'ellipsis', overflow: 'hidden' }
                        : {}),
                }, children: value })), enabled && (_jsx("div", { style: { display: 'table-cell', verticalAlign: 'middle' }, children: _jsx(Input, { style: {
                        inputWrapper: {
                            ...(!isValid && { borderColor: 'red' }),
                            width: '100%',
                        },
                        input: {
                            padding: '5px',
                            width: '100%',
                            minWidth: '60px',
                        },
                    }, autoSelect: true, className: "editable-column", value: val, type: type, onChange: handleChange, onKeyUp: editHandler, onMouseDown: (e) => e.stopPropagation(), ...InputProps }) }))] }));
});
export default EditableColumn;

==> nmrium-0.53.0.tgz: package/lib/component/elements/EditableColumn.js <==
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { forwardRef, useCallback, useEffect, useImperativeHandle, useState, } from 'react';
import Input from './Input';
function extractNumber(val, type) {
    if (type === 'number' && typeof val !== 'number') {
        return Number(val.replaceAll(/[^\d.-]/g, ''));
    }
    return val;
}
const EditableColumn = forwardRef(function EditableColumn(props, ref) {
    const { onSave = () => null, value, type = 'text', style, onEditStart = () => null, editStatus = false, validate = () => true, textOverFlowEllipses = false, ...InputProps } = props;
    const [enabled, enableEdit] = useState();
    const [isValid, setValid] = useState(true);
    const [val, setVal] = useState(extractNumber(value, type));
    useEffect(() => {
        enableEdit(editStatus);
    }, [editStatus]);
    useImperativeHandle(ref, () => ({
        startEdit: () => {
            enableEdit(true);
        },
        closeEdit: () => {
            enableEdit(false);
        },
    }));
    const mouseClickCallback = useCallback((e) => {
        if (!e.target.classList.contains('editable-column')) {
            enableEdit(false);
            window.removeEventListener('mousedown', mouseClickCallback);
        }
    }, []);
    function startEditHandler() {
        window.addEventListener('mousedown', mouseClickCallback);
        onEditStart(true);
        enableEdit(true);
    }
    function editHandler(event) {
        const valid = validate(val);
        setValid(valid);
        // when press Enter or Tab
        if (valid && ['Enter', 'Tab'].includes(event.key)) {
            onSave(event);
            enableEdit(false);
        }
        // close edit mode if press Enter, Tab or Escape
        if (['Escape'].includes(event.key)) {
            enableEdit(false);
            window.removeEventListener('mousedown', mouseClickCallback);
        }
    }
    function handleChange(e) {
        setVal(e.target.value);
    }
    return (_jsxs("div", { style: {
            display: 'table',
            width: '100%',
            height: '100%',
            ...(textOverFlowEllipses
                ? { whiteSpace: 'nowrap', overflow: 'hidden', display: 'inline-flex' }
                : {}),
            ...style,
        }, className: "editable-column-input", onDoubleClick: startEditHandler, children: [!enabled && (_jsxs("span", { style: {
                    display: 'table-cell',
                    verticalAlign: 'middle',
                    width: '100%',
                    ...(textOverFlowEllipses
                        ? { textOverflow: 'ellipsis', overflow: 'hidden' }
                        : {}),
                }, children: [value, " \u00A0"] })), enabled && (_jsx("div", { style: { display: 'table-cell', verticalAlign: 'middle' }, children: _jsx(Input, { style: {
                        inputWrapper: {
                            ...(!isValid && { borderColor: 'red' }),
                            width: '100%',
                        },
                        input: {
                            padding: '5px',
                            width: '100%',
                            minWidth: '60px',
                        },
                    }, autoSelect: true, className: "editable-column", value: val, type: type, onChange: handleChange, onKeyUp: editHandler, onMouseDown: (e) => e.stopPropagation(), ...InputProps }) }))] }));
});
export default EditableColumn;
